rufffmt
=======

[![Generated by attribution][attribution-badge]][attribution-url]


v1.0
----

Initial release

- Minimal LSP server
- Atomic file formatting

```text
$ git shortlog -s v1.0
    10	Amethyst Reese
     5	dependabot[bot]
```

[attribution-badge]:
    https://img.shields.io/badge/generated%20by-attribution-informational
[attribution-url]: https://attribution.omnilib.dev
